@@ -1,52 +1,39 @@
 from wowapi.connectors import APIConnector
-from wowapi.exceptions import APIError
+from wowapi.exceptions import WowApiError, WowApiClientError
 
 import json
 from mock import patch
+import pytest
 import requests
-import unittest
 
 
-class APIConnectorTest(unittest.TestCase):
+class TestAPIConnector:
 
-    def setUp(self):
+    @pytest.fixture(autouse=True)
+    def setup(self):
         self.host = "eu.battle.net"
 
     def test_get_query_parameters(self):
         instance = APIConnector(self.host, locale="en_GB", custom="test")
-        instance.allowed_filters = ["locale", ]
+        instance.filters = ["locale", ]
         url_parameters = instance.get_query_parameters()
-        self.assertEqual(1, len(url_parameters))
-        self.assertNotIn("custom", url_parameters)
+        assert 1, len(url_parameters)
+        assert "custom" not in url_parameters
 
     def test_get_url(self):
         instance = APIConnector(self.host, "guild", "player")
         url = instance.get_url()
-        self.assertEqual("http://eu.battle.net/api/wow/guild/player", url)
+        assert "http://eu.battle.net/api/wow/guild/player" == url
 
     def test_https(self):
         instance = APIConnector(self.host, "guild", "player", secure=True)
-        self.assertEqual("https://", instance.protocol)
+        assert "https://" == instance.protocol
 
-    def test_timeout(self):
+    def test_requests_error(self):
         instance = APIConnector(self.host)
         with patch.object(requests, 'get') as mock_method:
-            with self.assertRaises(APIError):
-                mock_method.side_effect = requests.Timeout
-                instance.handle_request('http://test')
-
-    def test_connection_error(self):
-        instance = APIConnector(self.host)
-        with patch.object(requests, 'get') as mock_method:
-            with self.assertRaises(APIError):
-                mock_method.side_effect = requests.ConnectionError
-                instance.handle_request('http://test')
-
-    def test_http_error(self):
-        instance = APIConnector(self.host)
-        with patch.object(requests, 'get') as mock_method:
-            with self.assertRaises(APIError):
-                mock_method.side_effect = requests.HTTPError
+            with pytest.raises(WowApiClientError):
+                mock_method.side_effect = requests.RequestException
                 instance.handle_request('http://test')
 
     @patch('requests.get')
@@ -54,14 +41,14 @@ class APIConnectorTest(unittest.TestCase):
         res = requests.models.Response()
         res.status_code = 404
         res._content = json.dumps({
-            "status":"nok",
+            "status": "nok",
             "reason": "something unexpected happened"
         })
 
         mock.return_value = res
         instance = APIConnector(self.host)
 
-        with self.assertRaises(APIError):
+        with pytest.raises(WowApiError):
             instance.handle_request('http://test')
 
     @patch('requests.get')
@@ -73,6 +60,5 @@ class APIConnectorTest(unittest.TestCase):
         mock.return_value = res
         instance = APIConnector(self.host)
 
-        with self.assertRaises(APIError):
+        with pytest.raises(WowApiClientError):
             instance.handle_request('http://test')
-
